@@ -9,9 +9,11 @@ package BaseClass;
 use Moose;
 use Moose::Util::MetaRole;
 BEGIN {
-    Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class => __PACKAGE__,
-        metaclass_roles => [qw/ BaseClass::Meta::Role /],
+    Moose::Util::MetaRole::apply_metaroles(
+        for             => __PACKAGE__,
+        class_metaroles => {
+            class => [qw/ BaseClass::Meta::Role /],
+        },
     );
 
     extends qw/MooseX::MethodAttributes::Inheritable/;
